@@ -282,6 +282,10 @@ class Base(Controller):
                 "action": "store",
                 "default": 5
             }),
+            (['-f','--file'],{
+                "help" : "File to be suggested from as context",
+                "action": "store"
+            }),
             (['-m','--model'],{
                 "help": "which model to use",
                 "action": "store",
@@ -300,7 +304,8 @@ class Base(Controller):
             else: model = self.app.pargs.model
             suggestions = get_cai_suggestions(self.app.pargs.text, 
                                               self.app.pargs.n_suggestions, 
-                                              model)
+                                              model,
+                                              self.app.pargs.file)
             try:
                 text = suggestions['choices'][0]['text']
                 pp.pprint(suggestions)
@@ -641,7 +646,7 @@ class Base(Controller):
         help='All Github related operations',
         arguments=[
              (['action'],{
-                "help" : """To show one of {ff, fs, contrib, diff}. \r\n
+                "help" : """To show one of {ff, fs, contrib, diff, branches}. \r\n
                 ff: Finds the forks of a repo.  \r\n
                 fs: Finds the last commit of a repo by fork. \r\n 
                 contrib: Finds the contributors of a repo. \r\n
@@ -651,7 +656,11 @@ class Base(Controller):
             (['-url'],{
                 # TODO: what if there's no forks to give?
                 "help" : "Github URL to search for forks."
-            })
+            }),
+            (['-r','--remote'],{
+                "help" : "The remote to search for forks.",
+                "action" : "store"
+            }),
         ]
     )
     def gh(self):
@@ -667,7 +676,55 @@ class Base(Controller):
         elif self.app.pargs.action=='diff':
             from ..ext.github import dir_diff
             pp(dir_diff(self.app.pargs.url))
+        elif self.app.pargs.action=='branches':
+            from ..ext.github import find_branches
+            
+            if self.app.pargs.remote is None: remote = True
+            else: remote = self.app.pargs.remote == 'True'
+            print(find_branches(self.app.pargs.url, remote))
+            
+    # create notes that are organized into project folders and are stored in md files
+    @ex(
+        help='Create notes that are organized into project folders and are stored in md files',
+        arguments=[
+            (['action'],{
+                "help" : "One of {add (screenshot), ls (notes), mk (project), rm (project), fin (note)}",
+                "action": "store"
+            }),
+            (['-t'],{
+                "help": "Text of the note",
+                "action": "store"
+            }),
+            (['-p'],{
+                "help" : "Project id. If not given, grabs the first one.",
+                "action" : 'store'
+            }),
+            (['-i'],{
+                "help" : "Id of the finished note",
+                "action": "store"
+            }),
+            (['-ws'],{
+                "help": "Workspace name (e.g. Daily) otherwiwise grabs the first one",
+                "action": "store"
+            })
+        ]
+    )
+    def nt(self):
+        from ..ext.notes import Note
+        note = Note(self.app.pargs.p, )
+        if self.app.pargs.action=='add':
+            note.add_attachment(self.app.pargs.p)
+        elif self.app.pargs.action=='ls':
+            note.ls(self.app.pargs.p, self.app.pargs.ws)
+        elif self.app.pargs.action=='mk':
+            note.create_project(self.app.pargs.p, self.app.pargs.t)
+        elif self.app.pargs.action=='up':
+            note.up(self.app.pargs.i, self.app.pargs.t, self.app.pargs.ws)
+        else:
+            print("Try one of {add, ls, dn}")
 
+    # create notes that are organized into project folders and are stored in md files
+    
 
     @ex(
         help='Manage TODOs using Asana',
